'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _printLine = require('./print-line');

var _printLine2 = _interopRequireDefault(_printLine);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var LogTypes = {
  log: 'LOG',
  info: 'INFO',
  warn: 'WARN',
  error: 'ERROR'
};

function makeConsoleMock(nativeConsole) {
  var _history = [];
  var groupDepth = 0;

  function prefix(str) {
    var underscores = Array(groupDepth).fill('_').join('');
    return underscores + str;
  }

  function log(logType) {
    for (var _len = arguments.length, msgs = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      msgs[_key - 1] = arguments[_key];
    }

    _history.push(_defineProperty({}, prefix(logType), msgs));
  }

  function group() {
    for (var _len2 = arguments.length, title = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      title[_key2] = arguments[_key2];
    }

    _history.push(_defineProperty({}, prefix('GROUP'), title));
    groupDepth += 1;
  }

  function groupEnd() {
    groupDepth = Math.max(0, groupDepth - 1);
  }

  function printHistory() {
    return _history.reduce(function (printedHistory, line) {
      return [printedHistory, (0, _printLine2.default)(line)].join('\n');
    }, '');
  }

  /* istanbul ignore next */
  function print() {
    if ((typeof nativeConsole === 'undefined' ? 'undefined' : _typeof(nativeConsole)) === 'object') {
      nativeConsole.log.apply(nativeConsole, arguments);
    } else {
      throw new Error(['[consolemock]', 'You called .print without giving makeConsoleMock a native console object:', "  import { makeConsoleMock } from 'consolemock';", '  console = makeConsoleMock(console);'].join('\n'));
    }
  }

  function clearHistory() {
    _history.length = 0;
  }

  return {
    group: group,
    groupEnd: groupEnd,
    print: print,
    printHistory: printHistory,
    clearHistory: clearHistory,
    history: function history() {
      return _history;
    },
    log: log.bind(null, LogTypes.log),
    info: log.bind(null, LogTypes.info),
    warn: log.bind(null, LogTypes.warn),
    error: log.bind(null, LogTypes.error)
  };
}

exports.default = makeConsoleMock;
module.exports = exports['default'];